@@ -1,15 +1,20 @@
 /**
  * Copyright (c) 2010 itemis AG (http://www.itemis.eu) and others.
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  */
 package org.eclipse.emf.codegen.ecore.xtext;
 
 
+import org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage;
+import org.eclipse.emf.ecore.EPackage;
+import org.eclipse.xtext.ISetup;
 import org.eclipse.xtext.resource.generic.AbstractGenericResourceSupport;
 
+import com.google.inject.Guice;
+import com.google.inject.Injector;
 import com.google.inject.Module;
 
 
@@ -37,11 +42,20 @@ import com.google.inject.Module;
  *
  * @author Sven Efftinge - Initial contribution and API
  */
-public class GenModelSupport extends AbstractGenericResourceSupport
+public class GenModelSupport extends AbstractGenericResourceSupport implements ISetup
 {
   @Override
   protected Module createGuiceModule()
   {
     return new GenModelRuntimeModule();
   }
+
+  public Injector createInjectorAndDoEMFRegistration()
+  {
+    Injector injector = Guice.createInjector(getGuiceModule());
+    injector.injectMembers(this);
+    registerInRegistry(false);
+    EPackage.Registry.INSTANCE.put(GenModelPackage.eNS_URI, GenModelPackage.eINSTANCE);
+    return injector;
+  }
 }
