@@ -1,9 +1,9 @@
 /**
  * Copyright (c) 2005-2007 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * http://www.eclipse.org/legal/epl-v20.html
  * 
  * Contributors: 
  *   IBM - Initial API and implementation
@@ -30,11 +30,11 @@ import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.Path;
 
 import org.eclipse.emf.codegen.ecore.Generator;
-import org.eclipse.emf.codegen.ecore.genmodel.GenJDKLevel;
 import org.eclipse.emf.codegen.ecore.genmodel.GenModel;
 import org.eclipse.emf.codegen.ecore.genmodel.GenModelFactory;
 import org.eclipse.emf.codegen.ecore.genmodel.GenModelPackage;
 import org.eclipse.emf.codegen.ecore.genmodel.GenPackage;
+import org.eclipse.emf.codegen.ecore.genmodel.util.GenModelUtil;
 import org.eclipse.emf.codegen.util.CodeGenUtil;
 import org.eclipse.emf.common.CommonPlugin;
 import org.eclipse.emf.common.util.AbstractTreeIterator;
@@ -471,7 +471,7 @@ public abstract class ModelImporter extends ModelConverter
 
     if (resource != null && !resource.getContents().isEmpty() && resource.getContents().get(0) instanceof GenModel)
     {
-      originalGenModel = (GenModel)resource.getContents().get(0);
+      originalGenModel = GenModelUtil.getGenModel(resource);
 
       setGenModelFileName(getOriginalGenModelPath().lastSegment());
       setGenModelContainerPath(getOriginalGenModelPath().removeLastSegments(1));
@@ -862,29 +862,7 @@ public abstract class ModelImporter extends ModelConverter
 
     if (getOriginalGenModel() == null)
     {
-      URI genModelURI = genModel.eResource().getURI();
-      if (genModelURI.isPlatformResource())
-      {
-        IFile genModelFile = ResourcesPlugin.getWorkspace().getRoot().getFile(new Path(genModelURI.toPlatformString(true)));
-        IProject project = genModelFile.getProject();
-        String complianceLevel = CodeGenUtil.EclipseUtil.getJavaComplianceLevel(project);
-        if ("1.5".equals(complianceLevel))
-        {
-          genModel.setComplianceLevel(GenJDKLevel.JDK50_LITERAL);
-        }
-        else if ("1.6".equals(complianceLevel))
-        {
-          genModel.setComplianceLevel(GenJDKLevel.JDK60_LITERAL);
-        }
-        else if ("1.7".equals(complianceLevel))
-        {
-          genModel.setComplianceLevel(GenJDKLevel.JDK70_LITERAL);
-        }
-        else if ("1.4".equals(complianceLevel))
-        {
-          genModel.setComplianceLevel(GenJDKLevel.JDK14_LITERAL);
-        }
-      }
+      genModel.initialize(true);
     }
   }
   
